@@ -27,9 +27,15 @@
 
 enum {
         TOUCHPAD_KEY,
+        TOUCHPAD_ON_KEY,
+        TOUCHPAD_OFF_KEY,
         MUTE_KEY,
         VOLUME_DOWN_KEY,
         VOLUME_UP_KEY,
+        MUTE_QUIET_KEY,
+        VOLUME_DOWN_QUIET_KEY,
+        VOLUME_UP_QUIET_KEY,
+        MIC_MUTE_KEY,
         POWER_KEY,
         EJECT_KEY,
         HOME_KEY,
@@ -37,6 +43,7 @@ enum {
         CALCULATOR_KEY,
         SEARCH_KEY,
         EMAIL_KEY,
+        CONTROL_CENTER_KEY,
         SCREENSAVER_KEY,
         HELP_KEY,
         WWW_KEY,
@@ -53,6 +60,9 @@ enum {
         SCREENREADER_KEY,
         ON_SCREEN_KEYBOARD_KEY,
         LOGOUT_KEY,
+        RFKILL_KEY,
+        BLUETOOTH_RFKILL_KEY,
+        DISPLAY_KEY,
         HANDLED_KEYS,
 };
 
@@ -63,9 +73,15 @@ static struct {
         Key *key;
 } keys[HANDLED_KEYS] = {
         { TOUCHPAD_KEY, "touchpad", NULL, NULL },
+        { TOUCHPAD_ON_KEY, NULL, "XF86TouchpadOn", NULL },
+        { TOUCHPAD_OFF_KEY, NULL, "XF86TouchpadOff", NULL },
         { MUTE_KEY, "volume-mute", NULL, NULL },
         { VOLUME_DOWN_KEY, "volume-down", NULL, NULL },
         { VOLUME_UP_KEY, "volume-up", NULL, NULL },
+        { MUTE_QUIET_KEY, "volume-mute-quiet", NULL, NULL },
+        { VOLUME_DOWN_QUIET_KEY, "volume-down-quiet", NULL, NULL },
+        { VOLUME_UP_QUIET_KEY, "volume-up-quiet", NULL, NULL },
+        { MIC_MUTE_KEY, "mic-mute", NULL, NULL },
         { POWER_KEY, "power", NULL, NULL },
         { EJECT_KEY, "eject", NULL, NULL },
         { HOME_KEY, "home", NULL, NULL },
@@ -73,6 +89,7 @@ static struct {
         { CALCULATOR_KEY, "calculator", NULL, NULL },
         { SEARCH_KEY, "search", NULL, NULL },
         { EMAIL_KEY, "email", NULL, NULL },
+        { CONTROL_CENTER_KEY, "control-center", NULL, NULL },
         { SCREENSAVER_KEY, "screensaver", NULL, NULL },
         { HELP_KEY, "help", NULL, NULL },
         { WWW_KEY, "www", NULL, NULL },
@@ -90,6 +107,9 @@ static struct {
         { SCREENREADER_KEY, "screenreader", NULL, NULL },
         { ON_SCREEN_KEYBOARD_KEY, "on-screen-keyboard", NULL, NULL },
         { LOGOUT_KEY, "logout", NULL, NULL },
+        { RFKILL_KEY, NULL, "XF86WLAN", NULL },
+        { BLUETOOTH_RFKILL_KEY, NULL, "XF86Bluetooth", NULL },
+        { DISPLAY_KEY, NULL, "XF86Display", NULL }
 };
 
 #endif /* __ACME_H__ */
